summaryrefslogtreecommitdiff
path: root/fpicker
diff options
context:
space:
mode:
authorLuboš Luňák <l.lunak@suse.cz>2011-04-28 15:01:22 +0200
committerLuboš Luňák <l.lunak@suse.cz>2011-04-28 15:01:22 +0200
commit7d597eaca6510276661096f5a99b1f53c7b1a2ec (patch)
tree97de3f0d457b7fdadb4a0521601852d86d89053e /fpicker
parent282d1e08446b9a0a33a3ceaad67f89624c00a3ba (diff)
OpenOffice.org -> LibreOffice
Diffstat (limited to 'fpicker')
-rw-r--r--fpicker/source/unx/kde/kdefpmain.cxx6
1 files changed, 3 insertions, 3 deletions
diff --git a/fpicker/source/unx/kde/kdefpmain.cxx b/fpicker/source/unx/kde/kdefpmain.cxx
index 2300fe61a2c4..be4022664014 100644
--- a/fpicker/source/unx/kde/kdefpmain.cxx
+++ b/fpicker/source/unx/kde/kdefpmain.cxx
@@ -51,10 +51,10 @@ static KCmdLineOptions sOptions[] =
int main( int argc, char* argv[] )
{
// we fake the name of the application to have "OpenOffice.org" in the
// title
- KAboutData qAboutData( "kdefilepicker", I18N_NOOP( "OpenOffice.org" ),
- "0.1", I18N_NOOP( "kdefilepicker is an implementation of the KDE file dialog for OpenOffice.org." ),
+ KAboutData qAboutData( "kdefilepicker", I18N_NOOP( "LibreOffice" ),
+ "0.1", I18N_NOOP( "kdefilepicker is an implementation of the KDE file dialog for LibreOffice." ),
KAboutData::License_LGPL,
"(c) 2004, Jan Holesovsky" );
qAboutData.addAuthor( "Jan Holesovsky", I18N_NOOP("Original author and current maintainer"), "kendy@openoffice.org" );
@@ -51,10 +51,10 @@ static KCmdLineOptions sOptions[] =
int main( int argc, char* argv[] )
{
- // we fake the name of the application to have "OpenOffice.org" in the
+ // we fake the name of the application to have "LibreOffice" in the
// title